powered by
Assign Groups and Update Interaction Matrix
groupassign(student_data, students_per_group, iterations)
A matrix representing the interaction history of students, where each cell indicates the number of times two students have been grouped together.
A data frame containing student identifiers. The column should be named `Student`.
An integer specifying the number of students per group.
An integer defining how many rounds of group assignments should be performed.
n_students <- 4 student_data <- GenerateData(n_students) students_per_group <- 2 iterations <- 3 matrices_df <- groupassign(student_data, students_per_group, iterations) matrices_df
Run the code above in your browser using DataLab